Module just

Module just 

Modules

model

Structs

TaskLogStore
In-memory ring buffer of recent task executions.

Enums

JustError

Functions

execute_recipe
Execute a recipe by name, passing args as positional parameters.
execute_recipe_merged
Execute a recipe resolved from a merged recipe list (project + optional global).
list_recipes
Discover recipes from the justfile at justfile_path.
list_recipes_merged
Discover and merge recipes from a project justfile and an optional global justfile.
resolve_justfile_path
Resolve justfile path from an optional override, workdir, or the current directory.
truncate_output
Truncate output to at most MAX_OUTPUT_BYTES.
validate_arg_value
Reject argument values that contain shell meta-characters.