Modules
Structs
- Task
LogStore - In-memory ring buffer of recent task executions.
Enums
Functions
- execute_
recipe - Execute a recipe by name, passing
argsas positional parameters. - execute_
recipe_ merged - Execute a recipe resolved from a merged recipe list (project + optional global).
- list_
recipes - Discover recipes from the justfile at
justfile_path. - list_
recipes_ merged - Discover and merge recipes from a project justfile and an optional global justfile.
- resolve_
justfile_ path - Resolve justfile path from an optional override, workdir, or the current directory.
- truncate_
output - Truncate output to at most
MAX_OUTPUT_BYTES. - validate_
arg_ value - Reject argument values that contain shell meta-characters.